package cn.com.ty.lift.business.capital.controller;

import cn.com.ty.lift.business.capital.dao.entity.CapitalRepair;
import cn.com.ty.lift.business.capital.dao.entity.model.CapitalRepairRequest;
import cn.com.ty.lift.business.capital.service.CapitalRepairService;
import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectResponse;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;

/**
 * @author bieao
 * @date 2020/2/3 12:21 下午
 * @description 大修项目控制层
 */
@RestController
@RequestMapping("capital/repair")
public class CapitalRepairController {

    @Resource
    private CapitalRepairService capitalRepairService;

    /**
     * @param request 大修项目列表查询条件
     * @return RestResponse 结果集
     * @description 条件查询大修项目列表
     * @date 2020/2/3 11:38 上午
     */
    @PostMapping("list")
    public RestResponse list(@Valid @RequestBody CapitalRepairRequest request) {
        IPage<ProjectResponse> page = capitalRepairService.list(request);
        if (CollUtil.isEmpty(page.getRecords())) {
            return RestResponse.success();
        }
        return RestResponse.success(page, MessageUtils.get("msg.query.success"));
    }

    /**
     * @param request 大修项目id
     * @return CapitalRepair 大修项目详情
     * @description 查询大修项目详情
     * @date 2020/2/3 11:31 上午
     */
    @PostMapping("detail")
    public RestResponse detail(@Valid @RequestBody CapitalRepairRequest request) {
        CapitalRepair capitalRepair = capitalRepairService.detail(request.getId());
        if (ObjectUtil.isEmpty(capitalRepair)) {
            return RestResponse.success();
        }
        return RestResponse.success(capitalRepair, MessageUtils.get("msg.query.detail.success"));
    }

    /**
     * @param capitalRepair 新增大修项目数据项
     * @return Integer 成功1或失败0
     * @description 新增大修项目
     * @date 2020/2/3 11:31 上午
     */
    @PostMapping("add")
    public RestResponse add(@RequestBody CapitalRepair capitalRepair) {
        boolean result= capitalRepairService.add(capitalRepair);
        if (result) {
            return RestResponse.success(null, MessageUtils.get("msg.add.success"));
        }
        return RestResponse.fail(MessageUtils.get("msg.add.fail"));
    }

    /**
     * @param capitalRepair 修改大修项目数据项
     * @return Integer 成功1或失败0
     * @description 修改大修项目
     * @date 2020/2/3 11:36 上午
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody CapitalRepair capitalRepair) {
        boolean result = capitalRepairService.modify(capitalRepair);
        if (result) {
            return RestResponse.success(null, MessageUtils.get("msg.modify.success"));
        }
        return RestResponse.fail(MessageUtils.get("msg.modify.fail"));
    }
}
