package cn.com.ty.lift.business.capital.service;

import cn.com.ty.lift.business.capital.dao.entity.CapitalRepair;
import cn.com.ty.lift.business.capital.dao.entity.model.CapitalRepairRequest;
import cn.com.ty.lift.business.capital.dao.mapper.CapitalRepairMapper;
import cn.com.ty.lift.business.project.dao.entity.model.response.ProjectResponse;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

/**
 * @author bieao
 * @date 2020/2/3 11:38 上午
 * @description 大修项目业务层
 */
@Service
public class CapitalRepairService extends ServiceImpl<CapitalRepairMapper, CapitalRepair> {

    /**
     * @param request 大修项目列表查询条件
     * @return RestResponse 结果集
     * @description 条件查询大修项目列表
     * @date 2020/2/3 11:38 上午
     */
    public IPage<ProjectResponse> list(CapitalRepairRequest request) {
        IPage<ProjectResponse> page = new Page<>(request.getPageNum(), request.getPageSize());
        return baseMapper.findByCondition(page, request);
    }

    /**
     * @param id 大修项目id
     * @return CapitalRepair 大修项目详情
     * @description 查询大修项目详情
     * @date 2020/2/3 11:31 上午
     */
    public CapitalRepair detail(Long id) {
        QueryWrapper<CapitalRepair> queryWrapper = new QueryWrapper<>();
        LambdaQueryWrapper<CapitalRepair> lambdaQueryWrapper = queryWrapper.lambda();
        lambdaQueryWrapper.eq(CapitalRepair::getId, id);
        return getOne(lambdaQueryWrapper);
    }

    /**
     * @param capitalRepair 新增大修项目数据项
     * @return Integer 成功1或失败0
     * @description 新增大修项目
     * @date 2020/2/3 11:31 上午
     */
    public boolean add(CapitalRepair capitalRepair) {
       return save(capitalRepair);
    }

    /**
     * @param capitalRepair 修改大修项目数据项
     * @return 是否成功
     * @description 修改大修项目
     * @date 2020/2/3 11:36 上午
     */
    public boolean modify(CapitalRepair capitalRepair) {
        return updateById(capitalRepair);
    }

}
